#!/bin/sh
#
# Creates a .tar.bz2 archive of the development directory.
#
# 1. parameter: name of the archive (without extension): kstreamripper or kstreamripper-unstable
# 2. parameter: version number (including .unstable for unstable releases!)
# 3. parameter: "stable" or "unstable", corresponding to the type of release.
# 4. parameter: if "make-devel-doc", then a devel-doc package will be created.
#
# If the archive exists yet, the old archive will be deleted.
SCRIPTDIR=`pwd`



echo "Creating archives"
rm -r -f ${SCRIPTDIR}/../../kstreamripper-release/$2
mkdir -p ${SCRIPTDIR}/../../kstreamripper-release
mkdir ${SCRIPTDIR}/../../kstreamripper-release/$2
if [ "$4" = "make-devel-doc" ]; # if third parameter is "make-devel-doc"...
then rm -r -f ${SCRIPTDIR}/../../kstreamripper-release/$2-devel-doc
mkdir ${SCRIPTDIR}/../../kstreamripper-release/$2-devel-doc
cd ${SCRIPTDIR}/../.. && tar -cf ${SCRIPTDIR}/../../kstreamripper-release/$2-devel-doc/kstreamripper-devel-doc-$2.tar kstreamripper/apidoc && bzip2 ${SCRIPTDIR}/../../kstreamripper-release/$2-devel-doc/kstreamripper-devel-doc-$2.tar
cp ${SCRIPTDIR}/../rpm/kstreamripper-devel-doc-$2.spec ${SCRIPTDIR}/../../kstreamripper-release/$2-devel-doc;
else rm ${SCRIPTDIR}/../rpm/*devel-doc*.spec;
fi
cd ${SCRIPTDIR} && ./remove-old-apidoc.sh
cd ${SCRIPTDIR}/../.. && tar -cf ${SCRIPTDIR}/../../kstreamripper-release/$2/$1-$2.tar kstreamripper && bzip2 ${SCRIPTDIR}/../../kstreamripper-release/$2/$1-$2.tar
cp ${SCRIPTDIR}/../rpm/$1-$2.spec ${SCRIPTDIR}/../../kstreamripper-release/$2
cd ${SCRIPTDIR}/../../kstreamripper-release/$2 && cp $1-$2.tar.bz2 $1_$2.orig.tar.bz2
cd ${SCRIPTDIR}/../deb && tar -cf ${SCRIPTDIR}/../../kstreamripper-release/$2/$1_$2.debian.tar debian && bzip2 ${SCRIPTDIR}/../../kstreamripper-release/$2/$1_$2.debian.tar
cd ${SCRIPTDIR}/../../kstreamripper-release/$2
ORIGMD5=`md5sum $1_$2.orig.tar.bz2 | sed -e "s/ *$1_$2.orig.tar.bz2//g"`
ORIGSIZE=`ls -l $1_$2.orig.tar.bz2 | sed -e "s/.* \([01-9][01-9][01-9][01-9]*\) .* $1_$2\.orig\.tar\.bz2.*/\1/g"`
DEBIANMD5=`md5sum $1_$2.debian.tar.bz2 | sed -e "s/ *$1_$2.debian.tar.bz2//g"`
DEBIANSIZE=`ls -l $1_$2.debian.tar.bz2 | sed -e "s/.* \([01-9][01-9][01-9][01-9]*\) .* $1_$2\.debian\.tar\.bz2.*/\1/g"`
cd ${SCRIPTDIR}/../../kstreamripper-release/$2 && cat ${SCRIPTDIR}/../templates/template.dsc | sed -e "s/%{files}/Files: \n $ORIGMD5 $ORIGSIZE $1_$2.orig.tar.bz2\n $DEBIANMD5 $DEBIANSIZE $1_$2.debian.tar.bz2/g" | sed -e "s/%{name}/$1/g" | sed -e "s/%{version}/Version: $2/g" > $1_$2.dsc
rm -f ${SCRIPTDIR}/../../kstreamripper-release/$2-devel-metapackage && mkdir -p ${SCRIPTDIR}/../../kstreamripper-release/$2-devel-metapackage && cp ${SCRIPTDIR}/../rpm/kstreamripper-devel-metapackage*.spec ${SCRIPTDIR}/../../kstreamripper-release/$2-devel-metapackage
echo "Done creating archives"



echo "Deleting old build service files"

# We substitute all line breaks with a simple space by using: paste -s -d' '
OLDFILES1=`osc list home:sommerluk:kstreamripper $1 | paste -s -d' '`
# do not stop the script on errors (here: if the directory exists yet)
set +e
osc rremove -f home:sommerluk:kstreamripper $1 ${OLDFILES1}
# switch back to default behavior
set -e

if [ "$4" = "make-devel-doc" ]; # if third parameter is "make-devel-doc"...
# We substitute all line breaks with a simple space by using: paste -s -d' '
then OLDFILES2=`osc list home:sommerluk:kstreamripper kstreamripper-devel-doc | paste -s -d' '`
# do not stop the script on errors (here: if the directory exists yet)
set +e
osc rremove -f home:sommerluk:kstreamripper kstreamripper-devel-doc ${OLDFILES2}
# switch back to default behavior
set -e;
fi

# We substitute all line breaks with a simple space by using: paste -s -d' '
OLDFILES3=`osc list home:sommerluk:kstreamripper kstreamripper-devel-metapackage | paste -s -d' '`
# do not stop the script on errors (here: if the directory exists yet)
set +e
osc rremove -f home:sommerluk:kstreamripper kstreamripper-devel-metapackage ${OLDFILES3}
# switch back to default behavior
set -e

echo "Done deleting old build service files"



echo "Submitting new build service files"
cd ${SCRIPTDIR}/../../kstreamripper-release && rm -r -f obs && mkdir obs && cd ${SCRIPTDIR}/../../kstreamripper-release/obs
osc co home:sommerluk:kstreamripper $1
osc co home:sommerluk:kstreamripper kstreamripper-devel-metapackage
cp ${SCRIPTDIR}/../../kstreamripper-release/$2/* ${SCRIPTDIR}/../../kstreamripper-release/obs/home:sommerluk:kstreamripper/$1
cp ${SCRIPTDIR}/../../kstreamripper-release/$2-devel-metapackage/* ${SCRIPTDIR}/../../kstreamripper-release/obs/home:sommerluk:kstreamripper/kstreamripper-devel-metapackage
if [ "$4" = "make-devel-doc" ]; # if third parameter is "make-devel-doc"...
then osc co home:sommerluk:kstreamripper kstreamripper-devel-doc
cp ${SCRIPTDIR}/../../kstreamripper-release/$2-devel-doc/* ${SCRIPTDIR}/../../kstreamripper-release/obs/home:sommerluk:kstreamripper/kstreamripper-devel-doc;
fi
cd ${SCRIPTDIR}/../../kstreamripper-release/obs/home:sommerluk:kstreamripper && osc addremove -r && osc commit --force -m "Automatic upload by create-archive.sh"
rm -r -f ${SCRIPTDIR}/../../kstreamripper-release/obs/*
echo "Done submitting new build service files"



cd ${SCRIPTDIR} && ./upload-to-sf.sh $2 $3
