#!/bin/sh
# (Re-)Generates the files that must have the version number of KStreamRipper.
# Expects the number as first argument.
# If the second argument is "stable", that a stable release is assumed.
# Than the version number is simply the number.
# Else the version number will be the number + "unstable".
SCRIPTDIR=`pwd`



echo "Setting version"

if [ "$2" = "stable" ]; # if second parameter is "stable"...
then DASHUNSTABLE=""
DOTUNSTABLE=""
CONFLICTS="  "
DEBCONFLICTS=""
CONFLICTSDOC="  "
DEBPROVIDES="Provides: kradioripper";
else DASHUNSTABLE="-unstable"
DOTUNSTABLE=".unstable"
CONFLICTS="Conflicts:                    kstreamripper  "
CONFLICTSDOC="Conflicts:                    kstreamripper-devel-doc  "
DEBCONFLICTS="Conflicts: kstreamripper\n"
DEBPROVIDES="Provides: kradioripper kstreamripper";
fi

head --lines=2 ${SCRIPTDIR}/../templates/version.h.cmake > ${SCRIPTDIR}/../src/version.h.cmake
echo '' >> ${SCRIPTDIR}/../src/version.h.cmake
echo '// WARNING: This file is generated by the script set-version.sh.' >> ${SCRIPTDIR}/../src/version.h.cmake
echo '// All changes you do to this file will be lost.' >> ${SCRIPTDIR}/../src/version.h.cmake
echo '/** \file' >> ${SCRIPTDIR}/../src/version.h.cmake
echo '  * This file is generated by the script <tt>set-version.sh</tt>.' >> ${SCRIPTDIR}/../src/version.h.cmake
echo '  * All changes you do to this file will be lost. */' >> ${SCRIPTDIR}/../src/version.h.cmake
if [ "$2" = "stable" ]; # if second parameter is "stable"...
then tail --lines=+3 ${SCRIPTDIR}/../templates/version.h.cmake | sed -e "s/^#define VERSION.*$/#define VERSION \"$1${DOTUNSTABLE}\"/g" | sed -e "s/^[   ]*#define[   ]*UNSTABLE.*//g" | sed -e "s/^[   /*]*\def[   ]*UNSTABLE.*//g" >> ${SCRIPTDIR}/../src/version.h.cmake;
else tail --lines=+3 ${SCRIPTDIR}/../templates/version.h.cmake | sed -e "s/^#define VERSION.*$/#define VERSION \"$1${DOTUNSTABLE}\"/g" >> ${SCRIPTDIR}/../src/version.h.cmake;
fi

rm -f ${SCRIPTDIR}/../rpm/*.spec

head --lines=1 ${SCRIPTDIR}/../templates/template.spec > ${SCRIPTDIR}/../rpm/kstreamripper${DASHUNSTABLE}-$1${DOTUNSTABLE}.spec
echo '# WARNING: This file is generated by the script set-version.sh.' >> ${SCRIPTDIR}/../rpm/kstreamripper${DASHUNSTABLE}-$1${DOTUNSTABLE}.spec
echo '# All changes you do to this file will be lost.' >> ${SCRIPTDIR}/../rpm/kstreamripper${DASHUNSTABLE}-$1${DOTUNSTABLE}.spec
if [ "$2" = "stable" ]; # if second parameter is "stable"...
then echo "Building stable release!";
else
echo '%define unstable 1' >> ${SCRIPTDIR}/../rpm/kstreamripper${DASHUNSTABLE}-$1${DOTUNSTABLE}.spec
fi
tail --lines=+2 ${SCRIPTDIR}/../templates/template.spec | sed -e "s/^Name:.*$/Name:                         kstreamripper${DASHUNSTABLE}  /g" | sed -e "s/^Version:.*$/Version:                      $1${DOTUNSTABLE}  /g" | sed -e "s/^Conflicts:.*$/${CONFLICTS}/g" >> ${SCRIPTDIR}/../rpm/kstreamripper${DASHUNSTABLE}-$1${DOTUNSTABLE}.spec

head --lines=1 ${SCRIPTDIR}/../templates/template2.spec > ${SCRIPTDIR}/../rpm/kstreamripper-devel-doc-$1${DOTUNSTABLE}.spec
echo '# WARNING: This file is generated by the script set-version.sh.' >> ${SCRIPTDIR}/../rpm/kstreamripper-devel-doc-$1${DOTUNSTABLE}.spec
echo '# All changes you do to this file will be lost.' >> ${SCRIPTDIR}/../rpm/kstreamripper-devel-doc-$1${DOTUNSTABLE}.spec
tail --lines=+2 ${SCRIPTDIR}/../templates/template2.spec | sed -e "s/^Name:.*$/Name:                         kstreamripper-devel-doc  /g" | sed -e "s/^Version:.*$/Version:                      $1${DOTUNSTABLE}  /g" | sed -e "s/^Conflicts:.*$/${CONFLICTSDOC}/g" >> ${SCRIPTDIR}/../rpm/kstreamripper-devel-doc-$1${DOTUNSTABLE}.spec

head --lines=1 ${SCRIPTDIR}/../templates/Doxyfile > ${SCRIPTDIR}/../apidoc/Doxyfile
echo '# WARNING: This file is generated by the script set-version.sh.' >> ${SCRIPTDIR}/../apidoc/Doxyfile
echo '# All changes you do to this file will be lost.' >> ${SCRIPTDIR}/../apidoc/Doxyfile
tail --lines=+2 ${SCRIPTDIR}/../templates/Doxyfile | sed -e "s/^PROJECT_NUMBER.*$/PROJECT_NUMBER         = $1${DOTUNSTABLE}/g" >> ${SCRIPTDIR}/../apidoc/Doxyfile

head --lines=1 ${SCRIPTDIR}/../templates/index.html > ${SCRIPTDIR}/../apidoc/index.html
echo '<!--' >> ${SCRIPTDIR}/../apidoc/index.html
echo '    WARNING: This file is generated by set-version.sh.' >> ${SCRIPTDIR}/../apidoc/index.html
echo '    All changes you do to this file will be lost.' >> ${SCRIPTDIR}/../apidoc/index.html
echo '-->' >> ${SCRIPTDIR}/../apidoc/index.html
tail --lines=+2 ${SCRIPTDIR}/../templates/index.html | sed -e "s/VERSION/version $1${DOTUNSTABLE}/g" >> ${SCRIPTDIR}/../apidoc/index.html

DATE=`date -R`
echo "kstreamripper${DASHUNSTABLE} ($1${DOTUNSTABLE}) lucid; urgency=low" > ${SCRIPTDIR}/../deb/debian/changelog
echo '' >> ${SCRIPTDIR}/../deb/debian/changelog
echo '  * Adopting for actual version' >> ${SCRIPTDIR}/../deb/debian/changelog
echo '' >> ${SCRIPTDIR}/../deb/debian/changelog
echo " -- Versioning script <nospam@please.com>  ${DATE}" >> ${SCRIPTDIR}/../deb/debian/changelog
echo '' >> ${SCRIPTDIR}/../deb/debian/changelog

cat ${SCRIPTDIR}/../templates/control | sed -e "s/%{name}/kstreamripper${DASHUNSTABLE}/g" | sed -e "s/%{conflicts}/${DEBCONFLICTS}/g" | sed -e "s/Provides:.*/${DEBPROVIDES}/g" > ${SCRIPTDIR}/../deb/debian/control

head --lines=1 ${SCRIPTDIR}/../templates/template-kstreamripper-devel-metapackage.spec > ${SCRIPTDIR}/../rpm/kstreamripper-devel-metapackage-$1${DOTUNSTABLE}.spec
echo '# WARNING: This file is generated by the script set-version.sh.' >> ${SCRIPTDIR}/../rpm/kstreamripper-devel-metapackage-$1${DOTUNSTABLE}.spec
echo '# All changes you do to this file will be lost.' >> ${SCRIPTDIR}/../rpm/kstreamripper-devel-metapackage-$1${DOTUNSTABLE}.spec
tail --lines=+2 ${SCRIPTDIR}/../templates/template-kstreamripper-devel-metapackage.spec | sed -e "s/^Version:.*/Version:       $1${DOTUNSTABLE}/g" >> ${SCRIPTDIR}/../rpm/kstreamripper-devel-metapackage-$1${DOTUNSTABLE}.spec

echo "Done setting version"
